@@ -14,8 +14,8 @@
 --
 --   * 'decode' etc. work as in @aeson >=0.9@
 --   * but it is generalised to work in any 'MonadThrow' (that is extra)
---   * '.:?' works as in @aeson <0.10@
---   * '.:!' works as '.:?' in @aeson ==0.10@
+--   * '.:?' works as in @aeson <0.10 || >=0.11@
+--   * '.:!' works as in @aeson <0.10 || >=0.11@ and as '.:?' did in @aeson ==0.10.*@
 --   * Orphan instances 'FromJSON' 'Day' and 'FromJSON' 'LocalTime' for @aeson <0.10@
 --   * 'Encoding' related functionality is not added. It's present only with @aeson >=0.10@
 --
@@ -54,11 +54,11 @@ module Data.Aeson.Compat (
     (.=),
 #endif
     -- ** Generic JSON classes and options
-    GFromJSON(..),
-    GToJSON(..),
+    GFromJSON,
+    GToJSON,
 #if MIN_VERSION_aeson(0,11,0)
     -- GToEncoding is introduced in 0.11.0.0
-    GToEncoding(..),
+    GToEncoding,
 #endif
     genericToJSON,
 #if MIN_VERSION_aeson(0,10,0)
@@ -123,7 +123,8 @@ import           Data.Typeable (Typeable)
 #if !MIN_VERSION_aeson(0,10,0)
 import           Data.Time (Day, LocalTime, formatTime, NominalDiffTime)
 import           Data.Time.Locale.Compat (defaultTimeLocale)
-import qualified Data.Aeson.Compat.Time as CompatTime
+import qualified Data.Attoparsec.Text as Atto
+import qualified Data.Attoparsec.Time as CompatTime
 #endif
 
 #if !(MIN_VERSION_aeson(0,11,0) && MIN_VERSION_base(4,8,0))
@@ -270,11 +271,16 @@ eitherDecodeStrictWith p to s =
 -----------------------------------------------------------------------
 
 #if !MIN_VERSION_aeson(0,10,0)
+attoRun :: Atto.Parser a -> Text -> Parser a
+attoRun p t = case Atto.parseOnly (p <* Atto.endOfInput) t of
+    Left err -> fail $ "could not parse date: " ++ err
+    Right r  -> return r
+
 instance FromJSON Day where
-  parseJSON = withText "Day" (CompatTime.run CompatTime.day)
+  parseJSON = withText "Day" (attoRun CompatTime.day)
 
 instance FromJSON LocalTime where
-  parseJSON = withText "LocalTime" (CompatTime.run CompatTime.localTime)
+  parseJSON = withText "LocalTime" (attoRun CompatTime.localTime)
 
 instance ToJSON Day where
   toJSON = toJSON . T.pack . formatTime defaultTimeLocale "%F"
@@ -285,12 +291,12 @@ instance ToJSON LocalTime where
 instance ToJSON NominalDiffTime where
   toJSON = Number . realToFrac
   {-# INLINE toJSON #-}
-	
+
 #if MIN_VERSION_aeson(0,10,0)
   toEncoding = Encoding . E.number . realToFrac
   {-# INLINE toEncoding #-}
 #endif
-	
+
 -- | /WARNING:/ Only parse lengths of time from trusted input
 -- since an attacker could easily fill up the memory of the target
 -- system by specifying a scientific number with a big exponent like
